==> dcl-c_5.3-1.tar.gz: dcl-c-5.3/src/grph2/uspack/usaxlb.c <==
/* src/grph2/uspack/usaxlb.f -- translated by f2c (version 20020621).
   You must link the resulting object file with the libraries:
	-lf2c -lm   (in that order)
*/

#include "libtinyf2c.h"

/* Table of constant values */

static logical c_true = TRUE_;

/* ----------------------------------------------------------------------- */
/*     USPACK AXIS (WITH LABEL)                        S.Sakai  99/10/05 */
/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
/* Subroutine */ int usaxlb_(char *cside, real *dtick, integer *n1, real *
	dlabel, char *ch, integer *nc, integer *n2, ftnlen cside_len, ftnlen 
	ch_len)
{
    /* System generated locals */
    integer i__1, i__2;

    /* Local variables */
    static integer i__, n;
    static char cs[1];
    static integer ncs;
    static real dlz[200], dtz[200];
    static logical loff;
    extern integer lenz_(char *, ftnlen);
    static real factor, offset;
    extern /* Subroutine */ int cupper_(char *, ftnlen), uxaxlb_(char *, real 
	    *, integer *, real *, char *, integer *, integer *, ftnlen, 
	    ftnlen), uyaxlb_(char *, real *, integer *, real *, char *, 
	    integer *, integer *, ftnlen, ftnlen), uzlget_(char *, logical *, 
	    ftnlen), uzlset_(char *, logical *, ftnlen), usxinz_(char *, real 
	    *, real *, ftnlen), usyinz_(char *, real *, real *, ftnlen), 
	    usxtlz_(void), usytlz_(void);

    /* Parameter adjustments */
    --dtick;
    ch -= ch_len;
    --dlabel;

    /* Function Body */
    uzlget_("LOFFSET", &loff, (ftnlen)7);
    uzlset_("LOFFSET", &c_true, (ftnlen)7);
    ncs = lenz_(cside, cside_len);
    i__1 = ncs;
    for (i__ = 1; i__ <= i__1; ++i__) {
	*(unsigned char *)cs = *(unsigned char *)&cside[i__ - 1];
	cupper_(cs, (ftnlen)1);
	if (*(unsigned char *)cs == 'T' || *(unsigned char *)cs == 'B' || *(
		unsigned char *)cs == 'H') {
	    if (*(unsigned char *)cs == 'H') {
		*(unsigned char *)cs = 'U';
	    }
	    usxinz_(cs, &factor, &offset, (ftnlen)1);
	    i__2 = *n1;
	    for (n = 1; n <= i__2; ++n) {
		dtz[n - 1] = (dtick[n] - offset) / factor;
/* L200: */
	    }
	    i__2 = *n2;
	    for (n = 1; n <= i__2; ++n) {
		dlz[n - 1] = (dlabel[n] - offset) / factor;
/* L210: */
	    }
	    uxaxlb_(cs, dtz, n1, dlz, ch + ch_len, nc, n2, (ftnlen)1, ch_len);
	    usxtlz_();
	} else if (*(unsigned char *)cs == 'L' || *(unsigned char *)cs == 'R' 
		|| *(unsigned char *)cs == 'V') {
	    if (*(unsigned char *)cs == 'V') {
		*(unsigned char *)cs = 'U';
	    }
	    usyinz_(cs, &factor, &offset, (ftnlen)1);
	    i__2 = *n1;
	    for (n = 1; n <= i__2; ++n) {
		dtz[n - 1] = (dtick[n] - offset) / factor;
/* L300: */
	    }
	    i__2 = *n2;
	    for (n = 1; n <= i__2; ++n) {
		dlz[n - 1] = (dlabel[n] - offset) / factor;
/* L310: */
	    }
	    uyaxlb_(cs, dtz, n1, dlz, ch + ch_len, nc, n2, (ftnlen)1, ch_len);
	    usytlz_();
	}
/* L100: */
    }
    uzlset_("LOFFSET", &loff, (ftnlen)7);
    return 0;
} /* usaxlb_ */

==> dcl-c_5.3.3.orig.tar.gz: dcl-c-5.3.3/src/grph2/uspack/usaxlb.c <==
/*  -- translated by f2c (version 20050501).
   You must link the resulting object file with libf2c:
	on Microsoft Windows system, link with libf2c.lib;
	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
	or, if you install libf2c.a in a standard place, with -lf2c -lm
	-- in that order, at the end of the command line, as in
		cc *.o -lf2c -lm
	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,

		http://www.netlib.org/f2c/libf2c.zip
*/

#include "libtinyf2c.h"

/* Table of constant values */

static logical c_true = TRUE_;

/* ----------------------------------------------------------------------- */
/*     USPACK AXIS (WITH LABEL)                        S.Sakai  99/10/05 */
/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
/* Subroutine */ int usaxlb_(char *cside, real *dtick, integer *n1, real *
	dlabel, char *ch, integer *nc, integer *n2, ftnlen cside_len, ftnlen 
	ch_len)
{
    /* System generated locals */
    integer i__1, i__2;

    /* Local variables */
    static integer i__, n;
    static char cs[1];
    static integer ncs;
    static real dlz[200], dtz[200];
    static logical loff;
    extern integer lenz_(char *, ftnlen);
    static real factor, offset;
    extern /* Subroutine */ int cupper_(char *, ftnlen), uxaxlb_(char *, real 
	    *, integer *, real *, char *, integer *, integer *, ftnlen, 
	    ftnlen), uyaxlb_(char *, real *, integer *, real *, char *, 
	    integer *, integer *, ftnlen, ftnlen), uzlget_(char *, logical *, 
	    ftnlen), uzlset_(char *, logical *, ftnlen), usxinz_(char *, real 
	    *, real *, ftnlen), usyinz_(char *, real *, real *, ftnlen), 
	    usxtlz_(void), usytlz_(void);

    /* Parameter adjustments */
    --dtick;
    ch -= ch_len;
    --dlabel;

    /* Function Body */
    uzlget_("LOFFSET", &loff, (ftnlen)7);
    uzlset_("LOFFSET", &c_true, (ftnlen)7);
    ncs = lenz_(cside, cside_len);
    i__1 = ncs;
    for (i__ = 1; i__ <= i__1; ++i__) {
	*(unsigned char *)cs = *(unsigned char *)&cside[i__ - 1];
	cupper_(cs, (ftnlen)1);
	if (*(unsigned char *)cs == 'T' || *(unsigned char *)cs == 'B' || *(
		unsigned char *)cs == 'H') {
	    if (*(unsigned char *)cs == 'H') {
		*(unsigned char *)cs = 'U';
	    }
	    usxinz_(cs, &factor, &offset, (ftnlen)1);
	    i__2 = *n1;
	    for (n = 1; n <= i__2; ++n) {
		dtz[n - 1] = (dtick[n] - offset) / factor;
/* L200: */
	    }
	    i__2 = *n2;
	    for (n = 1; n <= i__2; ++n) {
		dlz[n - 1] = (dlabel[n] - offset) / factor;
/* L210: */
	    }
	    uxaxlb_(cs, dtz, n1, dlz, ch + ch_len, nc, n2, (ftnlen)1, ch_len);
	    usxtlz_();
	} else if (*(unsigned char *)cs == 'L' || *(unsigned char *)cs == 'R' 
		|| *(unsigned char *)cs == 'V') {
	    if (*(unsigned char *)cs == 'V') {
		*(unsigned char *)cs = 'U';
	    }
	    usyinz_(cs, &factor, &offset, (ftnlen)1);
	    i__2 = *n1;
	    for (n = 1; n <= i__2; ++n) {
		dtz[n - 1] = (dtick[n] - offset) / factor;
/* L300: */
	    }
	    i__2 = *n2;
	    for (n = 1; n <= i__2; ++n) {
		dlz[n - 1] = (dlabel[n] - offset) / factor;
/* L310: */
	    }
	    uyaxlb_(cs, dtz, n1, dlz, ch + ch_len, nc, n2, (ftnlen)1, ch_len);
	    usytlz_();
	}
/* L100: */
    }
    uzlset_("LOFFSET", &loff, (ftnlen)7);
    return 0;
} /* usaxlb_ */
